# User Logs

These are API usage logs and are not for public consumption. They are used for debugging and monitoring purposes, and as such do not contain any sensitive information.

These logs do not indicate how the server is running. For that, please refer to the server logs.
